@@ -10,6 +10,8 @@
 #' @param page which page to render
 #' @param numeric convert raw output to (0-1) real values
 #' @param dpi resolution (dots per inch) to render
+#' @param antialias enable antialiasing. Must be `"text"` or `"draw"` or `TRUE` (both)
+#' or `FALSE` (neither).
 #' @param opw owner password
 #' @param upw user password
 #' @family pdftools
@@ -37,8 +39,10 @@
 #' bitmap_raw <- pdf_render_page("news.pdf", numeric = FALSE)
 #' webp::write_webp(bitmap_raw, "page.webp")
 #' }
-pdf_render_page<- function(pdf, page = 1, dpi = 72, numeric = FALSE, opw = "", upw = "") {
-  out <- poppler_render_page(loadfile(pdf), page, dpi, opw, upw)
+pdf_render_page<- function(pdf, page = 1, dpi = 72, numeric = FALSE, antialias = TRUE, opw = "", upw = "") {
+  antialiasing <- isTRUE(antialias) || isTRUE(antialias == "draw")
+  text_antialiasing <- isTRUE(antialias) || isTRUE(antialias == "text")
+  out <- poppler_render_page(loadfile(pdf), page, dpi, opw, upw, antialiasing, text_antialiasing)
   if(identical(dim(out)[1], 4L)){
     out <- out[c(3,2,1,4),,, drop = FALSE] ## convert ARGB to RGBA
   }
@@ -59,7 +63,8 @@ pdf_render_page<- function(pdf, page = 1, dpi = 72, numeric = FALSE, opw = "", u
 #' @param filenames vector of equal length to `pages` with output filenames. May also be
 #' a format string which is expanded using `pages` and `format` respectively.
 #' @param verbose print some progress info to stdout
-pdf_convert <- function(pdf, format = "png", pages = NULL, filenames = NULL , dpi = 72, opw = "", upw = "", verbose = TRUE){
+pdf_convert <- function(pdf, format = "png", pages = NULL, filenames = NULL , dpi = 72,
+                        antialias = TRUE, opw = "", upw = "", verbose = TRUE){
   config <- poppler_config()
   if(!config$can_render || !length(config$supported_image_formats))
     stop("You version of libppoppler does not support rendering")
@@ -74,7 +79,9 @@ pdf_convert <- function(pdf, format = "png", pages = NULL, filenames = NULL , dp
   }
   if(length(filenames) != length(pages))
     stop("Length of 'filenames' must be one or equal to 'pages'")
-  poppler_convert(loadfile(pdf), format, pages, filenames, dpi, opw, upw, verbose)
+  antialiasing <- isTRUE(antialias) || isTRUE(antialias == "draw")
+  text_antialiasing <- isTRUE(antialias) || isTRUE(antialias == "text")
+  poppler_convert(loadfile(pdf), format, pages, filenames, dpi, opw, upw, antialiasing, text_antialiasing, verbose)
 }
 
 
